[Pkg-telepathy-commits] [telepathy-glib-1] 96/212: Move TpSvc* registration code to the -dbus library

Simon McVittie smcv at debian.org
Wed May 14 12:08:56 UTC 2014


This is an automated email from the git hooks/post-receive script.

smcv pushed a commit to branch debian
in repository telepathy-glib-1.

commit 3783d1b549b423da8b17606e0bd417357e8c3973
Author: Simon McVittie <simon.mcvittie at collabora.co.uk>
Date:   Mon Mar 31 17:26:58 2014 +0100

    Move TpSvc* registration code to the -dbus library
    
    TpSvcInterfaceInfo encodes the assumption "we emit dbus-glib-style
    signals" which we don't want to keep forever. If we confine them to the
    -dbus library, it'll be easier to break its ABI.
    
    Bug: https://bugs.freedesktop.org/show_bug.cgi?id=76855
    Reviewed-by: Xavier Claessens
---
 .../telepathy-glib/telepathy-glib-docs.sgml        |  2 +-
 .../telepathy-glib/telepathy-glib-sections.txt     |  2 +-
 telepathy-glib/Makefile.am                         |  5 +-
 telepathy-glib/base-room-config.c                  |  1 +
 telepathy-glib/core-dbus.c                         | 62 --------------
 telepathy-glib/dbus-properties-mixin-internal.h    | 34 --------
 telepathy-glib/dbus-properties-mixin.c             | 35 +-------
 telepathy-glib/dbus-properties-mixin.h             |  6 --
 telepathy-glib/svc-interface-skeleton-internal.h   |  2 +-
 .../{core-svc-interface.c => svc-interface.c}      | 95 +++++++++++++++++++++-
 .../{core-svc-interface.h => svc-interface.h}      | 17 ++--
 telepathy-glib/telepathy-glib-dbus.h               |  1 +
 telepathy-glib/telepathy-glib.h                    |  1 -
 telepathy-glib/versions/core-1.0.abi               |  3 -
 telepathy-glib/versions/dbus-1.0.abi               |  4 +
 telepathy-glib/versions/main-1.0.abi               |  1 -
 tools/glib-ginterface-gen.py                       |  2 +-
 17 files changed, 118 insertions(+), 155 deletions(-)

diff --git a/docs/reference/telepathy-glib/telepathy-glib-docs.sgml b/docs/reference/telepathy-glib/telepathy-glib-docs.sgml
index 6e99cc2..73702cb 100644
--- a/docs/reference/telepathy-glib/telepathy-glib-docs.sgml
+++ b/docs/reference/telepathy-glib/telepathy-glib-docs.sgml
@@ -179,7 +179,7 @@
   <chapter id="ch-service-dbus">
     <title>Low-level generated code - service-side</title>
       <xi:include href="tp-svc.xml"/>
-      <xi:include href="xml/core-svc-interface.xml"/>
+      <xi:include href="xml/svc-interface.xml"/>
 
       <xi:include href="xml/svc-channel.xml"/>
       <xi:include href="xml/svc-channel-group.xml"/>
diff --git a/docs/reference/telepathy-glib/telepathy-glib-sections.txt b/docs/reference/telepathy-glib/telepathy-glib-sections.txt
index def44a9..b561318 100644
--- a/docs/reference/telepathy-glib/telepathy-glib-sections.txt
+++ b/docs/reference/telepathy-glib/telepathy-glib-sections.txt
@@ -6282,7 +6282,7 @@ TpLoggerPriv
 <SECTION>
 <INCLUDE>telepathy-glib/telepathy-glib.h</INCLUDE>
 <TITLE>TpSvcInterface</TITLE>
-<FILE>core-svc-interface</FILE>
+<FILE>svc-interface</FILE>
 TpSvcInterfaceInfo
 tp_svc_interface_peek_dbus_interface_info
 tp_svc_interface_set_dbus_interface_info
diff --git a/telepathy-glib/Makefile.am b/telepathy-glib/Makefile.am
index 18268e2..dd20cbf 100644
--- a/telepathy-glib/Makefile.am
+++ b/telepathy-glib/Makefile.am
@@ -85,7 +85,6 @@ tpginclude_HEADERS = \
     contact.h \
     contact-operations.h \
     base-contact-list.h \
-    core-svc-interface.h \
     dbus.h \
     dbus-properties-mixin.h \
     dbus-tube-channel.h \
@@ -156,6 +155,7 @@ tpgdbusinclude_HEADERS = \
     svc-connection-manager.h \
     svc-debug.h \
     svc-generic.h \
+    svc-interface.h \
     svc-properties-interface.h \
     svc-protocol.h \
     svc-tls.h \
@@ -194,7 +194,6 @@ libtelepathy_glib_core_internal_la_LIBADD = $(ALL_LIBS)
 libtelepathy_glib_core_internal_la_SOURCES = \
     core-dbus.c \
     core-proxy.c \
-    core-svc-interface.c \
     errors.c \
     $(NULL)
 
@@ -211,6 +210,7 @@ libtelepathy_glib_dbus_internal_la_SOURCES = \
     gtypes.c \
     interfaces.c \
     sliced-gvalue.c \
+    svc-interface.c \
     value-array.c \
     $(NULL)
 
@@ -292,7 +292,6 @@ libtelepathy_glib_main_internal_la_SOURCES = \
     dbus.c \
     dbus-internal.h \
     dbus-properties-mixin.c \
-    dbus-properties-mixin-internal.h \
     dbus-tube-channel.c \
     debug.c \
     debug-client.c \
diff --git a/telepathy-glib/base-room-config.c b/telepathy-glib/base-room-config.c
index bbda75d..1973b97 100644
--- a/telepathy-glib/base-room-config.c
+++ b/telepathy-glib/base-room-config.c
@@ -26,6 +26,7 @@
 #include <telepathy-glib/interfaces.h>
 #include <telepathy-glib/sliced-gvalue.h>
 #include <telepathy-glib/svc-channel.h>
+#include <telepathy-glib/svc-interface.h>
 #include <telepathy-glib/util.h>
 
 #define DEBUG_FLAG TP_DEBUG_ROOM_CONFIG
diff --git a/telepathy-glib/core-dbus.c b/telepathy-glib/core-dbus.c
index 48f0d4c..06a5812 100644
--- a/telepathy-glib/core-dbus.c
+++ b/telepathy-glib/core-dbus.c
@@ -22,7 +22,6 @@
 #include "config.h"
 
 #include "telepathy-glib/dbus.h"
-#include "telepathy-glib/dbus-properties-mixin-internal.h"
 #include "telepathy-glib/errors.h"
 
 /**
@@ -38,64 +37,3 @@ tp_dbus_g_method_return_not_implemented (GDBusMethodInvocation *context)
   g_dbus_method_invocation_return_dbus_error (context,
       TP_ERROR_STR_NOT_IMPLEMENTED, "Not implemented");
 }
-
-/* this is the core library, we don't have debug infrastructure yet */
-#define CRITICAL(format, ...) \
-  g_log (G_LOG_DOMAIN "/properties", G_LOG_LEVEL_CRITICAL, "%s: " format, \
-      G_STRFUNC, ##__VA_ARGS__)
-
-/**
- * tp_svc_interface_set_dbus_properties_info:
- * @g_interface: The #GType of a service interface
- * @info: an interface description
- *
- * Declare that @g_interface implements the given D-Bus interface, with the
- * given properties. This may only be called once per GInterface, usually from
- * a section of its base_init function that only runs once.
- *
- * This is typically only used within generated code; there is normally no
- * reason to call it manually.
- *
- * Since: 0.7.3
- */
-void
-tp_svc_interface_set_dbus_properties_info (GType g_interface,
-    TpDBusPropertiesMixinIfaceInfo *info)
-{
-  GQuark q = g_quark_from_static_string (
-        TP_SVC_INTERFACE_DBUS_PROPERTIES_MIXIN_QUARK_NAME);
-  TpDBusPropertiesMixinPropInfo *prop;
-
-  g_return_if_fail (G_TYPE_IS_INTERFACE (g_interface));
-  g_return_if_fail (g_type_get_qdata (g_interface, q) == NULL);
-  g_return_if_fail (info->dbus_interface != 0);
-  g_return_if_fail (info->props != NULL);
-
-  for (prop = info->props; prop->name != 0; prop++)
-    {
-      g_return_if_fail (prop->flags != 0);
-      g_return_if_fail (
-        (prop->flags & ~( TP_DBUS_PROPERTIES_MIXIN_FLAG_READ
-                        | TP_DBUS_PROPERTIES_MIXIN_FLAG_WRITE
-                        | TP_DBUS_PROPERTIES_MIXIN_FLAG_EMITS_CHANGED
-                        | TP_DBUS_PROPERTIES_MIXIN_FLAG_EMITS_INVALIDATED
-                        )) == 0);
-
-      /* Check that at most one change-related flag is set. */
-      if ((prop->flags & TP_DBUS_PROPERTIES_MIXIN_FLAG_EMITS_CHANGED) &&
-          (prop->flags & TP_DBUS_PROPERTIES_MIXIN_FLAG_EMITS_INVALIDATED))
-        {
-          CRITICAL ("at most one of EMITS_CHANGED and EMITS_INVALIDATED may be "
-              "specified for a property, but %s.%s has both",
-              g_quark_to_string (info->dbus_interface),
-              g_quark_to_string (prop->name));
-          g_return_if_reached ();
-        }
-
-      g_return_if_fail (prop->dbus_signature != NULL);
-      g_return_if_fail (prop->dbus_signature[0] != '\0');
-      g_return_if_fail (prop->type != 0);
-    }
-
-  g_type_set_qdata (g_interface, q, info);
-}
diff --git a/telepathy-glib/dbus-properties-mixin-internal.h b/telepathy-glib/dbus-properties-mixin-internal.h
deleted file mode 100644
index 2c9fab1..0000000
--- a/telepathy-glib/dbus-properties-mixin-internal.h
+++ /dev/null
@@ -1,34 +0,0 @@
-/*<private_header>*/
-/*
- * dbus-properties-mixin-internal.h - D-Bus core Properties
- * Copyright © 2008-2012 Collabora Ltd.
- * Copyright © 2008 Nokia Corporation
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
-
-#ifndef TELEPATHY_GLIB_DBUS_PROPERTIES_MIXIN_INTERNAL_H
-#define TELEPATHY_GLIB_DBUS_PROPERTIES_MIXIN_INTERNAL_H
-
-#include <telepathy-glib/dbus-properties-mixin.h>
-
-G_BEGIN_DECLS
-
-#define TP_SVC_INTERFACE_DBUS_PROPERTIES_MIXIN_QUARK_NAME \
-  "tp_svc_interface_get_dbus_properties_info"
-
-G_END_DECLS
-
-#endif
diff --git a/telepathy-glib/dbus-properties-mixin.c b/telepathy-glib/dbus-properties-mixin.c
index c834fb6..2886445 100644
--- a/telepathy-glib/dbus-properties-mixin.c
+++ b/telepathy-glib/dbus-properties-mixin.c
@@ -21,15 +21,13 @@
 #include "config.h"
 
 #include <telepathy-glib/dbus-properties-mixin.h>
-#include "telepathy-glib/dbus-properties-mixin-internal.h"
 
 #include <telepathy-glib/errors.h>
 #include <telepathy-glib/sliced-gvalue.h>
 #include <telepathy-glib/svc-generic.h>
+#include <telepathy-glib/svc-interface.h>
 #include <telepathy-glib/util.h>
 
-#include "telepathy-glib/dbus-properties-mixin-internal.h"
-
 #define DEBUG_FLAG TP_DEBUG_PROPERTIES
 #include "telepathy-glib/debug-internal.h"
 
@@ -130,37 +128,6 @@
  * Since: 0.7.3
  */
 
-static GQuark
-_iface_prop_info_quark (void)
-{
-  static GQuark q = 0;
-
-  if (G_UNLIKELY (q == 0))
-    q = g_quark_from_static_string (
-        TP_SVC_INTERFACE_DBUS_PROPERTIES_MIXIN_QUARK_NAME);
-
-  return q;
-}
-
-/**
- * tp_svc_interface_get_dbus_properties_info: (skip)
- * @g_interface: The #GType of a service interface
- *
- * Retrieves the D-Bus property metadata for the given interface, if any.
- * This function is typically not useful outside telepathy-glib itself, but may
- * be useful for domain-specific variations on the theme of SetProperty. If in
- * doubt, you probably don't need this function.
- *
- * Returns: D-Bus property metadata for @g_interface, or %NULL if it has
- *  none.
- * Since: 0.15.8
- */
-TpDBusPropertiesMixinIfaceInfo *
-tp_svc_interface_get_dbus_properties_info (GType g_interface)
-{
-  return g_type_get_qdata (g_interface, _iface_prop_info_quark ());
-}
-
 /**
  * TpDBusPropertiesMixinGetter:
  * @object: The exported object with the properties
diff --git a/telepathy-glib/dbus-properties-mixin.h b/telepathy-glib/dbus-properties-mixin.h
index 55c2bde..7a831c8 100644
--- a/telepathy-glib/dbus-properties-mixin.h
+++ b/telepathy-glib/dbus-properties-mixin.h
@@ -59,12 +59,6 @@ typedef struct {
     GCallback _2;
 } TpDBusPropertiesMixinIfaceInfo;
 
-void tp_svc_interface_set_dbus_properties_info (GType g_interface,
-    TpDBusPropertiesMixinIfaceInfo *info);
-_TP_AVAILABLE_IN_0_16
-TpDBusPropertiesMixinIfaceInfo *tp_svc_interface_get_dbus_properties_info (
-    GType g_interface);
-
 /* ---- Concrete implementation (in GObject subclasses) ------------- */
 
 typedef void (*TpDBusPropertiesMixinGetter) (GObject *object,
diff --git a/telepathy-glib/svc-interface-skeleton-internal.h b/telepathy-glib/svc-interface-skeleton-internal.h
index 0fb2dd7..f95e0db 100644
--- a/telepathy-glib/svc-interface-skeleton-internal.h
+++ b/telepathy-glib/svc-interface-skeleton-internal.h
@@ -22,7 +22,7 @@
 
 #include <gio/gio.h>
 
-#include <telepathy-glib/core-svc-interface.h>
+#include <telepathy-glib/svc-interface.h>
 #include <telepathy-glib/defs.h>
 
 G_BEGIN_DECLS
diff --git a/telepathy-glib/core-svc-interface.c b/telepathy-glib/svc-interface.c
similarity index 52%
rename from telepathy-glib/core-svc-interface.c
rename to telepathy-glib/svc-interface.c
index b440c14..3ae8297 100644
--- a/telepathy-glib/core-svc-interface.c
+++ b/telepathy-glib/svc-interface.c
@@ -17,10 +17,10 @@
  */
 
 #include <config.h>
-#include <telepathy-glib/core-svc-interface.h>
+#include <telepathy-glib/svc-interface.h>
 
 /**
- * SECTION:core-svc-interface
+ * SECTION:svc-interface
  * @title: TpSvcInterface
  * @short_description: glue to export `TpSvc` interfaces on D-Bus
  *
@@ -104,3 +104,94 @@ tp_svc_interface_set_dbus_interface_info (GType g_interface,
   /* g_type_set_qdata wants a non-const pointer */
   g_type_set_qdata (g_interface, quark (), (gpointer) info);
 }
+
+/* this is the core library, we don't have debug infrastructure yet */
+#define CRITICAL(format, ...) \
+  g_log (G_LOG_DOMAIN "/properties", G_LOG_LEVEL_CRITICAL, "%s: " format, \
+      G_STRFUNC, ##__VA_ARGS__)
+
+static GQuark
+_iface_prop_info_quark (void)
+{
+  static GQuark q = 0;
+
+  if (G_UNLIKELY (q == 0))
+    q = g_quark_from_static_string (
+        "tp_svc_interface_get_dbus_properties_info");
+
+  return q;
+}
+
+/**
+ * tp_svc_interface_get_dbus_properties_info: (skip)
+ * @g_interface: The #GType of a service interface
+ *
+ * Retrieves the D-Bus property metadata for the given interface, if any.
+ * This function is typically not useful outside telepathy-glib itself, but may
+ * be useful for domain-specific variations on the theme of SetProperty. If in
+ * doubt, you probably don't need this function.
+ *
+ * Returns: D-Bus property metadata for @g_interface, or %NULL if it has
+ *  none.
+ * Since: 0.15.8
+ */
+TpDBusPropertiesMixinIfaceInfo *
+tp_svc_interface_get_dbus_properties_info (GType g_interface)
+{
+  return g_type_get_qdata (g_interface, _iface_prop_info_quark ());
+}
+
+/**
+ * tp_svc_interface_set_dbus_properties_info:
+ * @g_interface: The #GType of a service interface
+ * @info: an interface description
+ *
+ * Declare that @g_interface implements the given D-Bus interface, with the
+ * given properties. This may only be called once per GInterface, usually from
+ * a section of its base_init function that only runs once.
+ *
+ * This is typically only used within generated code; there is normally no
+ * reason to call it manually.
+ *
+ * Since: 0.7.3
+ */
+void
+tp_svc_interface_set_dbus_properties_info (GType g_interface,
+    TpDBusPropertiesMixinIfaceInfo *info)
+{
+  GQuark q = _iface_prop_info_quark ();
+  TpDBusPropertiesMixinPropInfo *prop;
+
+  g_return_if_fail (G_TYPE_IS_INTERFACE (g_interface));
+  g_return_if_fail (g_type_get_qdata (g_interface, q) == NULL);
+  g_return_if_fail (info->dbus_interface != 0);
+  g_return_if_fail (info->props != NULL);
+
+  for (prop = info->props; prop->name != 0; prop++)
+    {
+      g_return_if_fail (prop->flags != 0);
+      g_return_if_fail (
+        (prop->flags & ~( TP_DBUS_PROPERTIES_MIXIN_FLAG_READ
+                        | TP_DBUS_PROPERTIES_MIXIN_FLAG_WRITE
+                        | TP_DBUS_PROPERTIES_MIXIN_FLAG_EMITS_CHANGED
+                        | TP_DBUS_PROPERTIES_MIXIN_FLAG_EMITS_INVALIDATED
+                        )) == 0);
+
+      /* Check that at most one change-related flag is set. */
+      if ((prop->flags & TP_DBUS_PROPERTIES_MIXIN_FLAG_EMITS_CHANGED) &&
+          (prop->flags & TP_DBUS_PROPERTIES_MIXIN_FLAG_EMITS_INVALIDATED))
+        {
+          CRITICAL ("at most one of EMITS_CHANGED and EMITS_INVALIDATED may be "
+              "specified for a property, but %s.%s has both",
+              g_quark_to_string (info->dbus_interface),
+              g_quark_to_string (prop->name));
+          g_return_if_reached ();
+        }
+
+      g_return_if_fail (prop->dbus_signature != NULL);
+      g_return_if_fail (prop->dbus_signature[0] != '\0');
+      g_return_if_fail (prop->type != 0);
+    }
+
+  g_type_set_qdata (g_interface, q, info);
+}
diff --git a/telepathy-glib/telepathy-glib-dbus.h b/telepathy-glib/telepathy-glib-dbus.h
index 6f1ac0d..be43929 100644
--- a/telepathy-glib/telepathy-glib-dbus.h
+++ b/telepathy-glib/telepathy-glib-dbus.h
@@ -67,6 +67,7 @@
 #include <telepathy-glib/svc-connection-manager.h>
 #include <telepathy-glib/svc-debug.h>
 #include <telepathy-glib/svc-generic.h>
+#include <telepathy-glib/svc-interface.h>
 #include <telepathy-glib/svc-properties-interface.h>
 #include <telepathy-glib/svc-protocol.h>
 #include <telepathy-glib/svc-tls.h>
diff --git a/telepathy-glib/telepathy-glib.h b/telepathy-glib/telepathy-glib.h
index 99b1392..c6a6700 100644
--- a/telepathy-glib/telepathy-glib.h
+++ b/telepathy-glib/telepathy-glib.h
@@ -66,7 +66,6 @@
 #include <telepathy-glib/channel.h>
 #include <telepathy-glib/client.h>
 #include <telepathy-glib/client-message.h>
-#include <telepathy-glib/core-svc-interface.h>
 #include <telepathy-glib/cm-message.h>
 #include <telepathy-glib/connection-contact-list.h>
 #include <telepathy-glib/connection-manager.h>
diff --git a/telepathy-glib/versions/core-1.0.abi b/telepathy-glib/versions/core-1.0.abi
index 3b0e683..e17f2df 100644
--- a/telepathy-glib/versions/core-1.0.abi
+++ b/telepathy-glib/versions/core-1.0.abi
@@ -16,6 +16,3 @@ tp_private_proxy_set_implementation
 tp_proxy_check_interface_by_id
 tp_proxy_pending_call_v1_new
 tp_proxy_signal_connection_v1_new
-tp_svc_interface_peek_dbus_interface_info
-tp_svc_interface_set_dbus_interface_info
-tp_svc_interface_set_dbus_properties_info
diff --git a/telepathy-glib/versions/dbus-1.0.abi b/telepathy-glib/versions/dbus-1.0.abi
index 9f7933e..cca7376 100644
--- a/telepathy-glib/versions/dbus-1.0.abi
+++ b/telepathy-glib/versions/dbus-1.0.abi
@@ -872,6 +872,10 @@ tp_svc_debug1_emit_new_debug_message
 tp_svc_debug1_get_type
 tp_svc_debug1_implement_get_messages
 tp_svc_debug1_return_from_get_messages
+tp_svc_interface_get_dbus_properties_info
+tp_svc_interface_peek_dbus_interface_info
+tp_svc_interface_set_dbus_interface_info
+tp_svc_interface_set_dbus_properties_info
 tp_svc_logger_emit_favourite_contacts_changed
 tp_svc_logger_get_type
 tp_svc_logger_implement_add_favourite_contact
diff --git a/telepathy-glib/versions/main-1.0.abi b/telepathy-glib/versions/main-1.0.abi
index 789d340..5c129d0 100644
--- a/telepathy-glib/versions/main-1.0.abi
+++ b/telepathy-glib/versions/main-1.0.abi
@@ -1109,7 +1109,6 @@ tp_stream_tube_connection_get_contact
 tp_stream_tube_connection_get_socket_connection
 tp_stream_tube_connection_get_type
 tp_strv_contains
-tp_svc_interface_get_dbus_properties_info
 tp_text_channel_ack_all_pending_messages_async
 tp_text_channel_ack_all_pending_messages_finish
 tp_text_channel_ack_message_async
diff --git a/tools/glib-ginterface-gen.py b/tools/glib-ginterface-gen.py
index d48ef17..184476d 100644
--- a/tools/glib-ginterface-gen.py
+++ b/tools/glib-ginterface-gen.py
@@ -741,9 +741,9 @@ class Generator(object):
         self.b('')
 
         if self.allow_single_include:
-            self.b('#include <telepathy-glib/core-svc-interface.h>')
             self.b('#include <telepathy-glib/dbus.h>')
             self.b('#include <telepathy-glib/dbus-properties-mixin.h>')
+            self.b('#include <telepathy-glib/svc-interface.h>')
             self.b('#include <telepathy-glib/util.h>')
             self.b('#include <telepathy-glib/value-array.h>')
         else:

diff --git a/telepathy-glib/core-svc-interface.h b/telepathy-glib/svc-interface.h
similarity index 72%
rename from telepathy-glib/core-svc-interface.h
rename to telepathy-glib/svc-interface.h
index 1ce3113..465ecff 100644
--- a/telepathy-glib/core-svc-interface.h
+++ b/telepathy-glib/svc-interface.h
@@ -16,16 +16,16 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #if !defined (_TP_GLIB_H_INSIDE) && !defined (_TP_COMPILATION)
 #error "Only <telepathy-glib/telepathy-glib.h> can be included directly."
 #endif
 
-#ifndef __TP_CORE_SVC_INTERFACE_H__
-#define __TP_CORE_SVC_INTERFACE_H__
+#ifndef __TP_SVC_INTERFACE_H__
+#define __TP_SVC_INTERFACE_H__
 
 #include <gio/gio.h>
 
-#include <telepathy-glib/defs.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 G_BEGIN_DECLS
 
@@ -46,6 +46,13 @@ void tp_svc_interface_set_dbus_interface_info (GType g_interface,
 const TpSvcInterfaceInfo *tp_svc_interface_peek_dbus_interface_info (
     GType g_interface);
 
+void tp_svc_interface_set_dbus_properties_info (GType g_interface,
+    TpDBusPropertiesMixinIfaceInfo *info);
+
+_TP_AVAILABLE_IN_0_16
+TpDBusPropertiesMixinIfaceInfo *tp_svc_interface_get_dbus_properties_info (
+    GType g_interface);
+
 G_END_DECLS
 
 #endif
@@ -16,16 +16,16 @@
  */
 
-#if !defined (_TP_GLIB_H_INSIDE) && !defined (_TP_COMPILATION)
-#error "Only <telepathy-glib/telepathy-glib.h> can be included directly."
+#if !defined (_TP_GLIB_DBUS_H_INSIDE) && !defined (_TP_COMPILATION)
+#error "Only <telepathy-glib/telepathy-glib-dbus.h> can be included directly."
 #endif
 
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-telepathy/telepathy-glib-1.git



More information about the Pkg-telepathy-commits mailing list